from discord.ext import commands


class Join(commands.Cog):
    """入室時の処理"""
    def __init__(self, bot):
        self.bot = bot
        self.id = self.bot.config['Daug']['guild_id']
        self.role_member_id = self.bot.config['Daug']['role_member_id']

    @commands.Cog.listener()
    async def on_member_join(self, member):
        if member.guild.id != self.id:
            return
        if member.bot:
            return
        role_member = member.guild.get_role(self.role_member_id)
        await member.add_roles(role_member)



def setup(bot):
    bot.load_extension('Daug.extensions.channels')
    bot.load_extension('Daug.extensions.favorite')
    bot.load_extension('Daug.extensions.join')
    bot.load_extension('Daug.extensions.leave')
    bot.load_extension('Daug.extensions.thread')
    bot.load_extension('Daug.extensions.utils')



import io
import discord
from time import time
from discord.ext import commands


def compose_channel_tree(guild):
    tree = []
    for category in guild.by_category():
        if category[0] is None:
            tree.append('C#')
        else:
            tree.append(f'C# {category[0].name}')
        for channel in category[1]:
            if isinstance(channel, discord.channel.TextChannel):
                tree.append(f'  T# {channel.name}')
            if isinstance(channel, discord.channel.VoiceChannel):
                tree.append(f'  V# {channel.name}')
    return '\n'.join(tree)


class Channels(commands.Cog):
    """チャンネル関連"""
    def __init__(self, bot):
        self.bot = bot

    @commands.group()
    @commands.guild_only()
    async def channels(self, ctx):
        if ctx.invoked_subcommand is None:
            await ctx.send('{} = Text:{} + Voice:{} + Category:{}'.format(
                len(ctx.guild.channels),
                len(ctx.guild.text_channels),
                len(ctx.guild.voice_channels),
                len(ctx.guild.categories),
            ))

    @channels.command()
    @commands.guild_only()
    async def tree(self, ctx):
        await ctx.send(
            file=discord.File(
                io.StringIO(compose_channel_tree(ctx.guild)),
                f'channels{int(time())}.txt',
            )
        )



from discord.ext import commands
from Daug.functions.embeds import compose_embed_from_description


class Utils(commands.Cog):
    def __init__(self, bot):
        self.bot = bot
        self.id = self.bot.config['Daug']['guild_id']

    @commands.command(aliases=['ch'])
    async def channel_count(self, ctx):
        count = len(ctx.guild.channels)
        await ctx.channel.send(embed=compose_embed_from_description(f'チャンネル数:{count}'))



from discord import Colour
from discord import Embed


def compose_embed_from_description(description):
    return Embed.from_dict({
        'description': description,
        'color': Colour.blue().value,
    })


def compose_embed_from_message(message):
    embed = Embed(
        description=message.content,
        timestamp=message.created_at,
    )
    embed.set_author(
        name=message.author.display_name,
        icon_url=message.author.avatar_url,
    )
    embed.set_footer(
        text=message.channel.name,
        icon_url=message.guild.icon_url,
    )
    if message.attachments and message.attachments[0].proxy_url:
        embed.set_image(
            url=message.attachments[0].proxy_url
        )
    return embed



from Daug.cogs import channels  # noqa: F401
from Daug.cogs import favorite  # noqa: F401
from Daug.cogs import join  # noqa: F401
from Daug.cogs import leave  # noqa: F401
from Daug.cogs import thread  # noqa: F401
from Daug.cogs import utils  # noqa: F401



from Daug.extensions import channels  # noqa: F401
from Daug.extensions import favorite  # noqa: F401
from Daug.extensions import join  # noqa: F401
from Daug.extensions import leave  # noqa: F401
from Daug.extensions import thread  # noqa: F401
from Daug.extensions import utils  # noqa: F401
